/**
 * Nodata SDK.
 */
import { ComponentFactoryResolver, ViewContainerRef } from '@angular/core';
import { ReplaySubject } from 'rxjs';
import { DatablockView, PresetFilter, GenericDashboard, PresetFilterView, PresetFilterMappingValue } from '@nodata/sdk';
import { DatablockViewComponent } from '../datablock-view';
import { SdkConfigService, CompilerService } from '../services';
export interface PinnableDatablockView {
    [datablockViewCode: string]: boolean;
}
export declare class DashboardComponent {
    private sdkConfig;
    private compilerService;
    private componentFactoryResolver;
    dashboardPlan: any;
    dashboardCode: string;
    pageCode: string;
    lazyLoading: boolean;
    readOnly: boolean;
    loaderHTML: string;
    externalPresetFilters: Array<PresetFilter>;
    presetFiltersMappingValue: PresetFilterMappingValue;
    afterUpdate: () => void;
    afterPageChange: (pageCode: string) => void;
    afterRenderJumpToPageCode: string;
    genericDashboard: GenericDashboard;
    pinnableDatablockView: PinnableDatablockView;
    overTheCracks: ViewContainerRef;
    private _datablockViewComponentList;
    private _presetFilterViewComponentList;
    private _textParser;
    private _datablockViewListSubject;
    private _datablockViewComponentListSubject;
    private _presetFilterViewListSubject;
    private _divId;
    private _isRendered;
    private _isLoading;
    private _componentsRef;
    /**
     * Constructor.
     * Generates the div identifier.
     */
    constructor(sdkConfig: SdkConfigService, compilerService: CompilerService, componentFactoryResolver: ComponentFactoryResolver);
    /**
     * Configures the presetfilterview from the inputs.
     */
    ngOnInit(): void;
    /**
     * Render the dashboard.
     */
    ngAfterViewInit(): void;
    /**
     * Render dashboard on dashboardCode or pageCode changes
     */
    ngOnChanges(changes: any): void;
    /**
     * Call destroy on dashboard.
     */
    ngOnDestroy(): void;
    /**
     * Call refresh on dashboard.
     */
    refresh(): void;
    /**
     * Getter for dashboard.
     */
    getDashboard(): GenericDashboard;
    /**
     * Get datablockView
     */
    getDatablockViewList(): ReplaySubject<Array<DatablockView>>;
    /**
     * Get datablockViewComponent
     */
    getDatablockViewComponentList(): ReplaySubject<Array<DatablockViewComponent>>;
    /**
     * Get presetFilterView
     */
    getPresetFilterViewList(): ReplaySubject<Array<PresetFilterView>>;
    /**
     * Get current slide page code
     */
    getCurrentSlidePageCode(): string;
    /**
     * Get current slide grid code
     */
    getCurrentSlideGridCode(): string;
    /**
     * Jump to slideshow page x
     */
    jumpTo(pageCode: string): void;
    /**
     * Jump to slideshow page number x (starting at 1 for the first slide)
     */
    jumpToPageNumber(index: string): void;
    /**
     * Render the current generic dashboard
     */
    render(atPage?: string): void;
    /**
     * If a dashboardCode is set,
     * renders its matching dashboard plan in a slideshow
     */
    private _renderDashboard;
    /**
     * Clear _datablockViewComponentList, _presetFilterViewComponentList and _componentsRef
     * to avoid memory leaks
     */
    private _clearComponentsRef;
    /**
     * Generate the internal div's identifier.
     * The identifier is meant to be unique to avoid conflicts.
     * At the moment, the only way to generate a unique identifier
     * with angular 2 is to use a UUID.
     */
    private _generateDivId;
    /**
     * Append the given image in the element
     */
    private _processImage;
    /**
     * Append the given text in the element
     */
    private _processText;
    /**
     * Append the given text in the element
     */
    private _processComment;
    /**
     * Generate a ComponentRef using either default ComponentFactoryResolver or Compiler service
     */
    private _generateCommentComponentRef;
    /**
     * Create a new DatablockView component,
     * gives it its parameters according to given content
     * and return the compiled html element
     */
    private _processDatablockView;
    /**
     * Create a new PresetFilterView component,
     * gives it its parameters according to given content
     * and return the compiled html element
     */
    private _processPresetFilterView;
    /**
     * Create dynamic component with html template given in parameter
     */
    private _createNewAngularComponent;
    /**
     * Create a new Angular component,
     * gives it its parameters according to given content
     * and return the compiled html element
     */
    private _processAngular;
    private _processPageLoad;
}
