/**
 * Nodata SDK.
 */
import { AfterViewInit, ViewContainerRef } from '@angular/core';
import { Observable } from 'rxjs';
import { Datablock, DatablockView, FilterCallback, CssClassesCallback, DrawTextCallback, OnCallback, OnZoomChangeCallback, EachCallback, AfterRenderCallback, AfterUpdateCallback } from '@nodata/sdk';
import { CompilerService, SdkConfigService } from '../services';
export declare class DatablockViewComponent implements AfterViewInit {
    private sdkConfig;
    private compilerService;
    datablock: Datablock;
    datablockView: DatablockView;
    lib: string;
    config: any;
    htmlTemplate: string;
    id: string;
    code: string;
    disableGlobalData: boolean;
    taskCode: string;
    data: Array<any>;
    dataEmptyHtml: string;
    dataEmptyMessage: string;
    loaderHTML: string;
    displayChartWhenDataEmpty: boolean;
    displayChartWhenLoading: boolean;
    pinnable: boolean;
    filter: FilterCallback;
    cssClasses: CssClassesCallback;
    drawText: DrawTextCallback;
    onMouseEnter: OnCallback;
    onMouseOver: OnCallback;
    onMouseLeave: OnCallback;
    onMouseOut: OnCallback;
    onClick: OnCallback;
    onZoomChange: OnZoomChangeCallback;
    afterRender: AfterRenderCallback;
    afterUpdate: AfterUpdateCallback;
    customFunction: Function | string;
    datablockViewContent: ViewContainerRef;
    private divId;
    private datablockViewSubject;
    private subscriptions;
    private datablockInputs;
    private datablockMapInputs;
    private destroyDatablock;
    private destroyDatablockView;
    private isDataEmpty;
    private componentRef;
    /**
     * Constructor.
     * Generates the div identifier.
     */
    constructor(sdkConfig: SdkConfigService, compilerService: CompilerService);
    /**
     * Configures the datablock from the inputs.
     */
    ngOnInit(): void;
    /**
     * Called when all the view bindings are resolved.
     * Configures the datablock from the inputs.
     * Fetches the output.
     * Executes the datablock.
     *
     * We are forced to do a setTimeout because of angular's lifecycle.
     * In debug mode, it double-checks if bound data has changed outside
     * of the first cycle.
     * As the datablock's state is used in the template, and modified when the datablock finishes its
     * render, angular interprets it as an internal bug.
     */
    ngAfterViewInit(): void;
    /**
     * Call destroy on datablock and datablock view.
     * But only if datablock and datablock view are created by the current datablock view component
     */
    ngOnDestroy(): void;
    /**
     * Calls the datablock view's update().
     * Waits for the datablock view to be initialized.
     */
    update(): void;
    /**
     * Calls the datablock view's redrawMap().
     * Waits for the datablock view to be initialized.
     */
    redrawMap(): void;
    /**
     * Calls the datablock view's resetZoom().
     * Waits for the datablock view to be initialized.
     */
    resetZoom(): void;
    /**
     * Calls the datablock view's center().
     * Waits for the datablock view to be initialized.
     */
    center(id: string): void;
    /**
     * Calls the datablock view's each().
     * Waits for the datablock view to be initialized.
     */
    each(callback: EachCallback): void;
    /**
     * Returns an Observable that completes when datablockView is initialized
     */
    getReadyDatablockView(): Observable<DatablockView>;
    /**
     * Generate the internal div's identifier.
     * The identifier is meant to be unique to avoid conflicts.
     * At the moment, the only way to generate a unique identifier
     * with angular 2 is to use a UUID.
     */
    private _generateDivId;
    /**
     * Configures the datablock from the inputs.
     * Initializes the datablock outputs array.
     */
    private _configureDatablock;
    /**
     * Returns the datablock inputs array.
     * The datablock inputs are a convenient way to bind this directive
     * with nodata sdk.
     */
    private _initDatablockViewInputs;
    /**
     * Returns the datablock inputs array for map.
     * The datablock inputs are a convenient way to bind this directive
     * with nodata sdk.
     */
    private _initDatablockViewMapInputs;
    /**
     * Executes the datablock if there is a task.
     * Renders the datablock view.
     */
    private _setupDatablockExecution;
    /**
     * Render angular if custom datablock, call datablockview.render otherwise
     */
    private _renderDatablockView;
    /**
     * Compile datablockView component
     */
    private _compileComponent;
    /**
     * Create dynamic component with html template given in parameter
     */
    private _createNewComponent;
    /**
     * Set isDataEmpty to true when data given in parameter is empty
     * When isDataEmpty is true, dataEmptyMessage message is displayed
     */
    private _setEmptyData;
    /**
     * Set all @Input callback to datablockview
     */
    private _setInputCallback;
    /**
     * Set all @Input callback to datablockview
     * Only available for map
     */
    private _setMapInputCallback;
    /**
     * Extracts the chart library in the ChartLib format from
     * the given string format.
     * e.g. 'witchart' becomes ChartLib.WITCHART.
     *
     * @param chartLib The chart library in string format.
     */
    private _extractChartLib;
    /**
     * Stringify the chart library in the current datablock view
     * e.g. 'ChartLib.WITCHART' becomes 'witchart'.
     */
    private _stringifyChartLib;
    /**
     * Call pinDatablockView sdkConfig callback with current datablockview
     */
    private _pinDatablockView;
}
