/**
 * Nodata SDK.
 */
import { SimpleChanges, ViewContainerRef } from '@angular/core';
import { DashboardComponent } from '../dashboard';
import { CompilerService, SdkConfigService } from '../services';
export interface InteractionIcon {
    class: string;
    image?: string;
}
export interface InteractionIconMap {
    [iconIdentifier: string]: InteractionIcon;
}
export declare class SlideTemplateComponent {
    private sdkConfig;
    private compilerService;
    dashboardPlan: any;
    dashboardCode: string;
    pageMetadata: any;
    pageCode: string;
    gridCode: string;
    interactionEnabled: boolean;
    pageTitleEditionEnabled: boolean;
    themesList: Object;
    loaderHTML: string;
    quillToolbar: Array<Array<any>>;
    advancedEdition: boolean;
    afterUpdate: () => void;
    interactionIcons: InteractionIconMap;
    /** Called when user click on datablockview resource */
    saveDatablockView: (resourceId: number) => void;
    dashboard: DashboardComponent;
    commentsListContainer: ViewContainerRef;
    private _nodata;
    private _comment;
    private _assetModel;
    private _pageModel;
    private _textParser;
    private _componentRef;
    private _gridTemplate;
    private _gridRows;
    private _gridCols;
    private _currentEditedCell;
    private _isEditingType;
    private _isRendering;
    private _isIncorrectImage;
    private _isLoading;
    private _isCommentsListLoading;
    private _isCommentsListLoaded;
    private _isEditingLabel;
    private _input;
    private _cancelImgUrl;
    private _commentImgUrl;
    private _copyImgUrl;
    private _deleteImgUrl;
    private _editImgUrl;
    private _graphImgUrl;
    private _imageImgUrl;
    private _infoImgUrl;
    private _textImgUrl;
    private _unpinImgUrl;
    private _validImgUrl;
    private _resourceType;
    private _themes;
    private _themesArray;
    private _commentsList;
    private _editedPesetFilterView;
    private _selectedPresetFilterValue;
    private _defaultInteractionIcons;
    /**
     * Constructor.
     * Generates the div identifier.
     */
    constructor(sdkConfig: SdkConfigService, compilerService: CompilerService);
    /**
     * Configures gridCode and dashboardCode to render grid properly
     */
    ngOnInit(): void;
    /**
     * Calls for a render of the grid when all html elements are rendered
     */
    ngAfterViewInit(): void;
    /**
     * Calls for a render of the grid when all html elements are rendered
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Call destroy on dashboard.
     */
    ngOnDestroy(): void;
    /**
     * Update current page label by calling upsert on a PageModel
     */
    private _updatePageLabel;
    /**
     * Fetch gridPlan according to given gridCode and dashboardCode
     * Then render it
     */
    private _renderGrid;
    /**
     * Set the _currentEditedCell the new zone type
     */
    private _addZone;
    /**
     * Display DatablockView's informations
     */
    private _cellInfo;
    /**
     * Empty the cell content, allowing it to be assigned again later
     */
    private _cellDelete;
    /**
     * Empty the cell and add the matching DatablockView in the Dock
     */
    private _cellUnpin;
    /**
     * Set the image properties of the _currentEditedCell
     */
    private _saveImageZone;
    /**
     * Set the text properties of the _currentEditedCell
     */
    private _saveTextZone;
    /**
     * Set the comments properties of the _currentEditedCell
     */
    private _saveCommentsZone;
    /**
     * Call saveDatablockView callback with current cell id
     */
    private _saveDatablockViewZone;
    /**
     * Set the PresetFilterView properties of the _currentEditedCell
     */
    private _savePresetFilterViewZone;
    /**
     * Call nodata's updateResource() method
     * Then reset editing variables
     * And render the grid according to the recent updates
     */
    private _updateResource;
    /**
     * Then reset editing variables
     */
    private _cancelEditing;
    /**
     * After selecting an image, check if it is not too heavy
     * Then display it as a preview in the editor container
     */
    private _imageInputChange;
    /**
     * Add a new empty entry in themesList
     */
    private _addTheme;
    /**
     * Removes given themeName entry from themesList
     */
    private _deleteTheme;
    /**
     * Get comments matching given ids
     * Then Extracts commen themes
     */
    private _fetchCommentsById;
    /**
     * Extracts from selected comments matching themes
     * Then search for all matching comments
     */
    private _extractCommentsThemes;
    /**
     * After cheking themesList, search for matching comments
     */
    private _commentsThemesInputChange;
    /**
     * Goes through themesList and cleanes it
     * Removing duplicate and empty values
     */
    private _checkThemes;
    /**
     * Quick workaround for Renault Qualif 7/11/17
     * Replace columns names with real themes names
     * ex: idStruc => region
     */
    private _mapThemes;
    /**
     * Goes through given newComments
     * If a comment is already in _commentsList, set it as selected
     */
    private _setComments;
    /**
     * Goes through _commentsList, deserializes its content and injects it in the DOM
     */
    private _displayComments;
    /**
     * Converts an Object to an Array
     */
    private _objectToArray;
    /**
     * Deduce the correct icon class for editor window according to editing type
     */
    private _getEditorContainerIcon;
    private _selectPresetFilterViewDefaultValue;
    /**
     * Fill interactionIcons with default values for missing properties
     */
    private _buildInteractionIcons;
}
